@@ -141,3 +141,14 @@ def slugify(string):
     slug = re.sub(r'[-\s]+', '-', no_punctuation)
     return u(slug)
 
+def int2byte(i):
+    """Converts an integer to a byte.
+    This is equivalent to chr() in Python 2 and bytes((i,)) in Python 3."""
+    return chr(i) if PY2 else bytes((i,))
+
+
+def byte2int(b):
+    """Converts a byte to an integer.
+    This is equivalent to ord(bs[0]) on Python 2 and bs[0] on Python 3."""
+    return ord(b)if PY2 else b
+
